@@ -67,14 +67,6 @@ LanLinkProvider::LanLinkProvider(bool testMode)
         qWarning() << "Error sending UDP packet:" << socketError;
     });
 
-#if QT_VERSION_MAJOR < 6
-    QNetworkConfigurationManager *networkManager = new QNetworkConfigurationManager(this);
-    connect(networkManager, &QNetworkConfigurationManager::configurationChanged, this, [this](QNetworkConfiguration config) {
-        if (config.state() == QNetworkConfiguration::Active) {
-            onNetworkChange();
-        }
-    });
-#else
     const auto checkNetworkChange = [this]() {
         if (QNetworkInformation::instance()->reachability() == QNetworkInformation::Reachability::Online) {
             onNetworkChange();
@@ -86,7 +78,6 @@ LanLinkProvider::LanLinkProvider(bool testMode)
     // We want to know if our current network reachability has changed, or if we change from one network to another
     connect(QNetworkInformation::instance(), &QNetworkInformation::reachabilityChanged, this, checkNetworkChange);
     connect(QNetworkInformation::instance(), &QNetworkInformation::transportMediumChanged, this, checkNetworkChange);
-#endif
 }
 
 LanLinkProvider::~LanLinkProvider()
@@ -268,8 +259,8 @@ void LanLinkProvider::udpBroadcastReceived()
             continue;
         }
 
-        if (receivedPacket->type() != PACKET_TYPE_IDENTITY) {
-            qCDebug(KDECONNECT_CORE) << "Received a UDP packet of wrong type" << receivedPacket->type();
+        if (!DeviceInfo::isValidIdentityPacket(receivedPacket)) {
+            qCWarning(KDECONNECT_CORE) << "Invalid identity packet received";
             delete receivedPacket;
             continue;
         }
@@ -486,8 +477,8 @@ void LanLinkProvider::dataReceived()
         return;
     }
 
-    if (np->type() != PACKET_TYPE_IDENTITY) {
-        qCWarning(KDECONNECT_CORE) << "LanLinkProvider/newConnection: Expected identity, received " << np->type();
+    if (!DeviceInfo::isValidIdentityPacket(np)) {
+        qCWarning(KDECONNECT_CORE) << "Invalid identity packet received";
         delete np;
         return;
     }
@@ -536,14 +527,7 @@ void LanLinkProvider::configureSslSocket(QSslSocket *socket, const QString &devi
     // Configure for ssl
     QSslConfiguration sslConfig;
     sslConfig.setLocalCertificate(KdeConnectConfig::instance().certificate());
-
-    QFile privateKeyFile(KdeConnectConfig::instance().privateKeyPath());
-    QSslKey privateKey;
-    if (privateKeyFile.open(QIODevice::ReadOnly)) {
-        privateKey = QSslKey(privateKeyFile.readAll(), QSsl::Rsa);
-    }
-    privateKeyFile.close();
-    sslConfig.setPrivateKey(privateKey);
+    sslConfig.setPrivateKey(KdeConnectConfig::instance().privateKey());
 
     if (isDeviceTrusted) {
         QSslCertificate certificate = KdeConnectConfig::instance().getTrustedDeviceCertificate(deviceId);
@@ -556,11 +540,11 @@ void LanLinkProvider::configureSslSocket(QSslSocket *socket, const QString &devi
     socket->setPeerVerifyName(deviceId);
 
     // Usually SSL errors are only bad for trusted devices. Uncomment this section to log errors in any case, for debugging.
-    // QObject::connect(socket, static_cast<void (QSslSocket::*)(const QList<QSslError>&)>(&QSslSocket::sslErrors), [](const QList<QSslError>& errors)
-    //{
-    //     Q_FOREACH (const QSslError& error, errors) {
-    //         qCDebug(KDECONNECT_CORE) << "SSL Error:" << error.errorString();
-    //     }
+    // connect(socket, &QSslSocket::sslErrors, [](const QList<QSslError>& errors)
+    // {
+    //      for (const QSslError& error : errors) {
+    //          qCDebug(KDECONNECT_CORE) << "SSL Error:" << error.errorString();
+    //      }
     // });
 }
 
