@@ -76,7 +76,7 @@ KdeConnectKcm::KdeConnectKcm(QObject *parent, const KPluginMetaData &md, const Q
     connect(kcmUi.renameShow_button, &QAbstractButton::clicked, this, &KdeConnectKcm::renameShow);
     connect(kcmUi.pluginSelector, &KPluginWidget::changed, this, &KdeConnectKcm::pluginsConfigChanged);
 
-    if (!args.isEmpty() && args.first().type() == QVariant::String) {
+    if (!args.isEmpty() && !args.first().isNull() && args.first().canConvert<QString>()) {
         const QString input = args.first().toString();
         const auto colonIdx = input.indexOf(QLatin1Char(':'));
         const QString deviceId = input.left(colonIdx);
@@ -180,7 +180,7 @@ void KdeConnectKcm::resetCurrentDevice()
 
 void KdeConnectKcm::resetDeviceView()
 {
-    kcmUi.verificationKey->setText(i18n("Key: %1", QString::fromUtf8(currentDevice->verificationKey())));
+    kcmUi.verificationKey->setText(i18n("Key: %1", currentDevice->verificationKey()));
 
     kcmUi.name_label->setText(currentDevice->name());
     setWhenAvailable(
